More endpoint_location coverage.
diff --git a/openstack/endpoint_location.go b/openstack/endpoint_location.go
index bd1d820..5a311e4 100644
--- a/openstack/endpoint_location.go
+++ b/openstack/endpoint_location.go
@@ -52,13 +52,13 @@
 	return "", gophercloud.ErrEndpointNotFound
 }
 
 // V3EndpointLocator discovers the endpoint URL for a specific service using multiple calls against
 // an identity v3 service endpoint. The specified EndpointOpts are used to identify a unique,
 // unambiguous endpoint to return. It's an error both when multiple endpoints match the provided
 // criteria and when none do. The minimum that can be specified is a Type, but you will also often
 // need to specify a Name and/or a Region depending on what's available on your OpenStack
 // deployment.
-func V3EndpointLocator(v3Client *gophercloud.ServiceClient, opts gophercloud.EndpointOpts) (string, error) {
+func V3EndpointURL(v3Client *gophercloud.ServiceClient, opts gophercloud.EndpointOpts) (string, error) {
 	// Discover the service we're interested in.
 	var services = make([]services3.Service, 0, 1)
 	servicePager := services3.List(v3Client, services3.ListOpts{ServiceType: opts.Type})
@@ -52,13 +52,13 @@
 }
 
-// V3EndpointLocator discovers the endpoint URL for a specific service using multiple calls against
+// V3EndpointURL discovers the endpoint URL for a specific service using multiple calls against
 // an identity v3 service endpoint. The specified EndpointOpts are used to identify a unique,
 // unambiguous endpoint to return. It's an error both when multiple endpoints match the provided